@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: DistUtil.py 12425 2020-07-26 06:31:20Z Bear $
+# $Id: DistUtil.py 13288 2021-09-01 13:04:30Z Tiffany $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, and individual contributors.
 # All rights reserved.
@@ -30,9 +30,9 @@
 # OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-# $Author: Bear $ (last)
-# $Date: 2020-07-26 14:31:20 +0800 (Sun, 26 Jul 2020) $
-# $Revision: 12425 $
+# $Author: Tiffany $ (last)
+# $Date: 2021-09-01 21:04:30 +0800 (週三, 01 九月 2021) $
+# $Revision: 13288 $
 """
 Distribution utilities.
 """
@@ -288,9 +288,16 @@ def setup(name,
     """   
     supportReinstall(name)
     
+    import pip
     from setuptools import setup as setuptoolsSetup
     from setuptools import find_packages
+    from pkg_resources import packaging
     
+    if packaging.version.parse(pip.__version__) >= packaging.version.parse("21.0.0"):
+        raise RuntimeError(
+            "pip version < 21.0.0 is required\n"
+            "execute 'python -m pip install pip==20.2.4' to downgrade pip"
+        )
     _createManifestFile()         
     sitePackagesDir = getSitePackagesDir()   
 
@@ -383,31 +390,31 @@ def setup(name,
                    
     setuptoolsSetup(**kws)    
     
-    # if 'bdist_wheel' in sys.argv:
-    #     print(("%s" % colored(
-    #         ("\n"
-    #          "---------------------------------------------------------"
-    #          "\n"
-    #          "Only 'sdist upload' and 'install' command will work properly."
-    #          "\n"
-    #          "\n"
-    #          "bdist_wheel not supported for this package. \n"
-    #          "If using egg install,\n"
-    #          "Some package would not be installed properly,\n"
-    #          "patch would not be executed either.\n"
-    #          "---------------------------------------------------------"
-    #          "\n"
-    #          "See more details: \n"
-    #          "https://code.nuwainfo.com/trac/mercurius/ticket/2646#comment:5"
-    #          "\n"
-    #          "https://code.nuwainfo.com/trac/mercurius/ticket/2643#comment:28"
-    #          "\n"
-    #          "https://code.nuwainfo.com/trac/Mercurius/ticket/2933#comment:25"
-    #          "\n"
-    #          "---------------------------------------------------------"
-    #          ), 'yellow', attrs=['bold'])
-    #     ))
-    #     raise NotImplementedError("bdist_wheel not supported for this package.")
+    if 'bdist_wheel' in sys.argv:
+        print(("%s" % colored(
+            ("\n"
+             "---------------------------------------------------------"
+             "\n"
+             "Only 'sdist upload' and 'install' command will work properly."
+             "\n"
+             "\n"
+             "bdist_wheel not supported for this package. \n"
+             "If using egg install,\n"
+             "Some package would not be installed properly,\n"
+             "patch would not be executed either.\n"
+             "---------------------------------------------------------"
+             "\n"
+             "See more details: \n"
+             "https://code.nuwainfo.com/trac/mercurius/ticket/2646#comment:5"
+             "\n"
+             "https://code.nuwainfo.com/trac/mercurius/ticket/2643#comment:28"
+             "\n"
+             "https://code.nuwainfo.com/trac/Mercurius/ticket/2933#comment:25"
+             "\n"
+             "---------------------------------------------------------"
+             ), 'yellow', attrs=['bold'])
+        ))
+        raise NotImplementedError("bdist_wheel not supported for this package.")
     
     # patch
     if 'install' in sys.argv or 'bdist_wheel' in sys.argv:
